@@ -91,6 +91,9 @@ private slots:
     void invalidFormat();
     void nullFormat();
 
+    void start_withSupportedSampleFormats_data();
+    void start_withSupportedSampleFormats();
+
     void bufferSize_data();
     void bufferSize();
     void bufferSize_getValidDefault();
@@ -98,6 +101,7 @@ private slots:
     void bufferSize_updatedAfterStart();
 
     void stopWhileStopped();
+    void stopWhileSuspended();
     void suspendWhileStopped();
     void resumeWhileStopped();
 
@@ -421,6 +425,38 @@ void tst_QAudioSink::nullFormat()
     }
 }
 
+void tst_QAudioSink::start_withSupportedSampleFormats_data()
+{
+    QTest::addColumn<QAudioFormat::SampleFormat>("sampleFormat");
+    for (auto sampleFormat : audioDevice.supportedSampleFormats()) {
+        QTest::newRow(QStringLiteral("Sample format: %1").arg(sampleFormat).toUtf8().constData())
+                      << sampleFormat;
+    }
+}
+
+void tst_QAudioSink::start_withSupportedSampleFormats()
+{
+    // Arrange
+    AudioPullSource source(true);
+    source.open(QIODevice::ReadOnly);
+
+    QFETCH(QAudioFormat::SampleFormat, sampleFormat);
+    QAudioFormat format = audioDevice.preferredFormat();
+    format.setSampleFormat(sampleFormat);
+    QAudioSink sink(audioDevice, format);
+
+    QSignalSpy stateSignal(&sink, &QAudioSink::stateChanged);
+
+    // Act
+    sink.start(&source);
+
+    // Assert
+    QTRY_COMPARE(stateSignal.count(), 1);
+    QCOMPARE(sink.state(), QAudio::ActiveState);
+    QCOMPARE(sink.error(), QAudio::NoError);
+    QTRY_COMPARE_GT(sink.processedUSecs(), 0);
+}
+
 void tst_QAudioSink::bufferSize_data()
 {
     QTest::addColumn<int>("bufferSize");
@@ -508,6 +544,22 @@ void tst_QAudioSink::stopWhileStopped()
              "error() was not set to QAudio::NoError after stop()");
 }
 
+void tst_QAudioSink::stopWhileSuspended()
+{
+    using namespace std::chrono_literals;
+
+    QAudioSink audioSink(audioDevice.preferredFormat(), this);
+    audioSink.start();
+    QTest::qWait(10ms); // give WASAPI worker thread a bit of time to arrive at WaitForSingleObject
+
+    audioSink.suspend();
+    QTRY_COMPARE_EQ(audioSink.state(), QAudio::SuspendedState);
+    QTest::qWait(10ms); // give WASAPI worker thread a bit of time to arrive at WaitForSingleObject
+
+    audioSink.stop();
+    QTRY_COMPARE_EQ(audioSink.state(), QAudio::StoppedState);
+}
+
 void tst_QAudioSink::suspendWhileStopped()
 {
     // Calls QAudioSink::suspend() when object is already in StoppedState
@@ -752,8 +804,12 @@ void tst_QAudioSink::pullResumeFromUnderrun()
 
     QTRY_COMPARE(stateSignal.size(), 1);
     QCOMPARE(audioSink.state(), QAudio::IdleState);
+    QT_WARNING_PUSH;
+    QT_WARNING_DISABLE_DEPRECATED;
     if (underrunIsAnError())
         QCOMPARE(audioSink.error(), QAudio::UnderrunError);
+    QT_WARNING_POP;
+
     stateSignal.clear();
 
     QTest::qWait(300);
@@ -1133,9 +1189,13 @@ void tst_QAudioSink::pushUnderrun()
                      .toUtf8()
                      .constData());
     QVERIFY2((audioSink.state() == QAudio::IdleState), "didn't transition to IdleState, no data");
-    if (underrunIsAnError())
+    if (underrunIsAnError()) {
+        QT_WARNING_PUSH;
+        QT_WARNING_DISABLE_DEPRECATED;
         QVERIFY2((audioSink.error() == QAudio::UnderrunError),
                  "error state is not equal to QAudio::UnderrunError, no data");
+        QT_WARNING_POP;
+    }
     stateSignal.clear();
 
     // Play rest of the clip
